@@ -1,10 +1,9 @@
 # Locale::Po4a::Pod -- Convert POD data to PO file, for translation.
-# $Id: Pod.pm,v 1.22 2009-02-09 23:11:56 nekral-guest Exp $
 #
 # This program is free software; you may redistribute it and/or modify it
 # under the terms of GPL (see COPYING file).
 #
-# This module converts POD to PO file, so that it becomes possible to 
+# This module converts POD to PO file, so that it becomes possible to
 # translate POD formatted documentation. See gettext documentation for
 # more info about PO files.
 
@@ -13,7 +12,7 @@
 ############################################################################
 
 use Pod::Parser;
-use Locale::Po4a::TransTractor qw(process new);
+use Locale::Po4a::TransTractor qw(process new get_out_charset);
 
 package Locale::Po4a::Pod;
 
@@ -72,17 +71,22 @@ sub command {
     my ($self, $command, $paragraph, $line_num) = @_;
 #    print STDOUT "cmd: '$command' '$paragraph' at $line_num\n";
     if ($command eq 'back'
-	|| $command eq 'cut'
-	|| $command eq 'pod') {
-	$self->pushline("=$command\n\n");
+        || $command eq 'cut'
+        || $command eq 'pod') {
+        $self->pushline("=$command\n\n");
     } elsif ($command eq 'over') {
-	$self->pushline("=$command $paragraph".(length($paragraph)?"":"\n\n"));
+        $self->pushline("=$command $paragraph".(length($paragraph)?"":"\n\n"));
+    } elsif ($command eq 'encoding') {
+        my $charset = $paragraph;
+        $charset =~ s/^\s*(.*?)\s*$/$1/s;
+        $self->detected_charset($charset)
+        # The =encoding line will be added by docheader
     } else {
-	$paragraph=$self->translate($paragraph,
-				    $self->input_file().":$line_num",
-				    "=$command",
-				    "wrap"=>1);
-	$self->pushline("=$command $paragraph\n\n");
+        $paragraph=$self->translate($paragraph,
+                                    $self->input_file().":$line_num",
+                                    "=$command",
+                                    "wrap"=>1);
+        $self->pushline("=$command $paragraph\n\n");
     }
 }
 
@@ -91,12 +95,12 @@ sub verbatim {
 #    print "verb: '$paragraph' at $line_num\n";
 
     if ($paragraph eq "\n") {
-	$self->pushline("$paragraph\n");
-	return;
+        $self->pushline("$paragraph\n");
+        return;
     }
     $paragraph=$self->translate($paragraph,
-				$self->input_file().":$line_num",
-				"verbatim");
+                                $self->input_file().":$line_num",
+                                "verbatim");
     $paragraph =~ s/\n$//m;
     $self->pushline("$paragraph\n");
 }
@@ -105,7 +109,7 @@ sub textblock {
     my ($self, $paragraph, $line_num) = @_;
 #    print "text: '$paragraph' at $line_num\n";
 
-    # Fix a pretty damned bug. 
+    # Fix a pretty damned bug.
     # Podlators don't wrap explicitelly the text, and groff won't seem to
     #  wrap any line begining with a space. So, we have to consider as
     #  verbatim not only the paragraphs whose first line is indented, but
@@ -114,18 +118,18 @@ sub textblock {
     #  that's harmless (only less confortable for translators).
 
     if ($paragraph eq "\n") {
-	$self->pushline("$paragraph\n");
-	return;
+        $self->pushline("$paragraph\n");
+        return;
     }
     if ($paragraph =~ m/^[ \t]/m) {
-	$self->verbatim($paragraph, $line_num) ;
-	return;
+        $self->verbatim($paragraph, $line_num) ;
+        return;
     }
 
     $paragraph=$self->translate($paragraph,
-				$self->input_file().":$line_num",
-				'textblock',
-				"wrap"=>1);
+                                $self->input_file().":$line_num",
+                                'textblock',
+                                "wrap"=>1);
     $paragraph=~ s/ +\n/\n/gm;
     $self->pushline("$paragraph\n\n");
 }
@@ -146,8 +150,10 @@ sub parse {
 
 sub docheader {
     my $self=shift;
-    my $encoding = $self->{TT}{file_out_charset};
-    if (defined $encoding) {
+    my $encoding = $self->get_out_charset();
+    if (    (defined $encoding)
+        and (length $encoding)
+        and ($encoding ne "ascii")) {
         $encoding = "\n=encoding $encoding\n";
     } else {
         $encoding = "";
@@ -156,15 +162,15 @@ sub docheader {
     return <<EOT;
 
         *****************************************************
-        *           GENERATED FILE, DO NOT EDIT             * 
+        *           GENERATED FILE, DO NOT EDIT             *
         * THIS IS NO SOURCE FILE, BUT RESULT OF COMPILATION *
         *****************************************************
 
-This file was generated by po4a(7). Do not store it (in cvs, for example),
-but store the po file used as source file by po4a-translate. 
+This file was generated by po4a(7). Do not store it (in VCS, for example),
+but store the PO file used as source file by po4a-translate.
 
-In fact, consider this as a binary, and the po file as a regular .c file:
-If the po get lost, keeping this translation up-to-date will be harder.
+In fact, consider this as a binary, and the PO file as a regular .c file:
+If the PO get lost, keeping this translation up-to-date will be harder.
 $encoding
 EOT
 }
@@ -177,9 +183,11 @@ EOT
 1;
 __END__
 
+=encoding UTF-8
+
 =head1 NAME
 
-Locale::Po4a::Pod - Convert POD data from/to PO files
+Locale::Po4a::Pod - convert POD data from/to PO files
 
 =head1 SYNOPSIS
 
@@ -200,25 +208,24 @@ the POD format (the preferred language for documenting Perl) into other
 
 =head1 STATUS OF THIS MODULE
 
-I think that this module is rock stable, and there is only one known bug:
-
-I have another problem with /usr/lib/perl5/Tk/MainWindow.pod (and some other
+I think that this module is rock stable, and there is only one known bug
+with F</usr/lib/perl5/Tk/MainWindow.pod> (and some other
 pages, see below) which contains:
 
-  CE<lt>" #n"E<gt>
+  C<" #n">
 
-Lack of luck, in the po4a version, this was splited on the space by the
-wrapping. As result, in the original version, the man contain 
+Lack of luck, in the po4a version, this was split on the space by the
+wrapping. As result, in the original version, the man page contains
 
  " #n"
 
-and mine contain
+and mine contains
 
  "" #n""
- 
-which is logic since C<foobar> is rewritten "foobar"
 
-Complete list of pages having this problem on my box (from 564 pages ; note
+which is logic since CE<lt>foobarE<gt> is rewritten "foobar".
+
+Complete list of pages having this problem on my box (from 564 pages; note
 that it depends on the chosen wrapping column):
 /usr/lib/perl5/Tk/MainWindow.pod
 /usr/share/perl/5.8.0/overload.pod
@@ -244,51 +251,51 @@ children are:
 
 =over 4
 
-=item alt
+=item B<alt>
 
 If set to a true value, selects an alternate output format that, among other
-things, uses a different heading style and marks C<=item> entries with a
+things, uses a different heading style and marks B<=item> entries with a
 colon in the left margin.  Defaults to false.
 
-=item code
+=item B<code>
 
 If set to a true value, the non-POD parts of the input file will be included
 in the output.  Useful for viewing code documented with POD blocks with the
 POD rendered and the code left intact.
 
-=item indent
+=item B<indent>
 
 The number of spaces to indent regular text, and the default indentation for
-C<=over> blocks.  Defaults to 4.
+B<=over> blocks.  Defaults to 4.
 
-=item loose
+=item B<loose>
 
-If set to a true value, a blank line is printed after a C<=head1> heading.
-If set to false (the default), no blank line is printed after C<=head1>,
-although one is still printed after C<=head2>.  This is the default because
+If set to a true value, a blank line is printed after a B<=head1> heading.
+If set to false (the default), no blank line is printed after B<=head1>,
+although one is still printed after B<=head2>.  This is the default because
 it's the expected formatting for manual pages; if you're formatting
 arbitrary text documents, setting this to true may result in more pleasing
 output.
 
-=item quotes
+=item B<quotes>
 
 Sets the quote marks used to surround CE<lt>> text.  If the value is a
 single character, it is used as both the left and right quote; if it is two
 characters, the first character is used as the left quote and the second as
-the right quoted; and if it is four characters, the first two are used as
+the right quote; and if it is four characters, the first two are used as
 the left quote and the second two as the right quote.
 
-This may also be set to the special value C<none>, in which case no quote
+This may also be set to the special value B<none>, in which case no quote
 marks are added around CE<lt>> text.
 
-=item sentence
+=item B<sentence>
 
 If set to a true value, Locale::Po4a::Pod will assume that each sentence
 ends in two spaces, and will try to preserve that spacing.  If set to
 false, all consecutive whitespace in non-verbatim paragraphs is compressed
 into a single space.  Defaults to true.
 
-=item width
+=item B<width>
 
 The column at which to wrap text on the right-hand side.  Defaults to 76.
 
@@ -296,8 +303,10 @@ The column at which to wrap text on the right-hand side.  Defaults to 76.
 
 =head1 SEE ALSO
 
-L<Pod::Parser>, L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>,
+L<Pod::Parser>,
 L<Locale::Po4a::Man(3pm)>,
+L<Locale::Po4a::TransTractor(3pm)>,
+L<po4a(7)|po4a.7>
 
 =head1 AUTHORS
 
