@@ -64,6 +64,17 @@ These are this module's particular options:
 
 =over
 
+=item B<keyvalue>
+
+Treat paragraphs that look like a key value pair as verbatim (with the no-wrap flag in the PO file).
+Key value pairs are defined as a line containing one or more non-colon
+and non-space characters followed by a colon followed by at least one
+non-space character before the end of the line.
+
+=cut
+
+my $keyvalue = 0;
+
 =item B<nobullets>
 
 Deactivate detection of bullets.
@@ -150,6 +161,14 @@ A comma-separated list of tags to be translated can be provided.
 
 my %control = ();
 
+=item B<neverwrap>
+
+Prevent po4a from wrapping lines.
+
+=cut
+
+my $neverwrap = 0;
+
 my $parse_func = \&parse_fallback;
 
 my @comments = ();
@@ -170,8 +189,10 @@ sub initialize {
     $self->{options}{'fortunes'} = 1;
     $self->{options}{'markdown'} = 1;
     $self->{options}{'nobullets'} = 1;
+    $self->{options}{'keyvalue'} = 1;
     $self->{options}{'tabs'} = 1;
     $self->{options}{'verbose'} = 1;
+    $self->{options}{'neverwrap'} = 1;
 
     foreach my $opt (keys %options) {
         die wrap_mod("po4a::text",
@@ -180,6 +201,11 @@ sub initialize {
         $self->{options}{$opt} = $options{$opt};
     }
 
+    if (defined $options{'keyvalue'}) {
+        $keyvalue = 1;
+        print "setting keyvalue\n";
+    }
+
     if (defined $options{'nobullets'}) {
         $bullets = 0;
     }
@@ -192,6 +218,10 @@ sub initialize {
         $breaks = $options{'breaks'};
     }
 
+    if (defined $options{'neverwrap'}) {
+        $neverwrap = 1;
+    }
+
     if (defined $options{'debianchangelog'}) {
         $parse_func = \&parse_debianchangelog;
     }
@@ -289,7 +319,7 @@ sub parse_debianchangelog {
         $paragraph="";
         $self->pushline("$line\n");
         $expect_header=0;
-    } elsif ($line =~ m/^ \-\- (.*) <(.*)>  ((\w+\,\s*)?\d{1,2}\s+\w+\s+\d{4}\s+\d{1,2}:\d\d:\d\d\s+[-+]\d{4}(\s+\([^\\\(\)]\))?)$/) {
+    } elsif ($line =~ m/^ \-\- (.*) <(.*)>  ((\w+\,\s*)?\d{1,2}\s+\w+\s+\d{4}\s+\d{1,2}:\d\d:\d\d\s+[-+]\d{4}(\s+\([^\\\(\)]+\)))$/) {
         # Found trailer
         do_paragraph($self,$paragraph,$wrapped_mode);
         $paragraph="";
@@ -808,6 +838,9 @@ sub parse {
                           or $paragraph =~ m/[ \t][ \t][ \t]/s);
         $wrapped_mode = 0 if (    $tabs eq "verbatim"
                               and $paragraph =~ m/\t/s);
+        # Also consider keyvalue paragraphs verbatim, if requested
+        $wrapped_mode = 0 if (    $keyvalue == 1
+                              and $paragraph =~ m/^[^ :]+:.*[^\s].*$/s);
         if ($markdown) {
             # Some Markdown markup can (or might) not survive wrapping
             $wrapped_mode = 0 if (
@@ -838,6 +871,8 @@ sub do_paragraph {
     my $type = shift || $self->{type} || "Plain text";
     return if ($paragraph eq "");
 
+	$wrap = 0 if $neverwrap;
+
 # DEBUG
 #    my $b;
 #    if (defined $self->{bullet}) {
