@@ -1,11 +1,20 @@
 #! /usr/bin/perl
 #  Remove header entry of two PO files and compare them
 
+my $ignore_ref = 0;
 my $f1 = shift(@ARGV);
+
+if ($f1 =~ /--no-ref/) {
+    $ignore_ref = 1;
+    $f1 = shift(@ARGV);
+}
+
 my $f2 = shift(@ARGV);
 
 open IN1, "<", $f1 or die "Unable to read 1st file: $!\n";
 open IN2, "<", $f2 or die "Unable to read 2nd file: $!\n";
+
+# Skip headers
 my $inMsgstr = 0;
 my $lineno = 0;
 while (<IN1>) {
@@ -26,10 +35,14 @@ while (<IN2>) {
 }
 
 # Now compare lines
-while (<IN1>) {
-	$lineno ++;
-	my $l2 = <IN2> or die "Unexpected EOF found when reading $f2\n";
-	$_ eq $l2 or die "Files $f1 and $f2 differ at line $lineno:\n-$_+$l2\n";
+foreach my $l1 (<IN1>) {
+    $lineno ++;
+
+    my $l2 = <IN2> or die "Unexpected EOF found when reading $f2\n";
+
+    unless (($l1 eq $l2) or ($ignore_ref and ($l1 =~ m/^#:/) and ($l2 =~ m/^#:/))) {
+	die "Files $f1 and $f2 differ at line $lineno:\n-${l1}+${l2}\n";
+    }
 }
 close IN1;
 die "EOF expected at 2nd file\n" unless eof(IN2);
